package org.jeecg.api.service;

import org.jeecg.api.bean.CommonHomeBo;
import org.jeecg.api.bean.HousePageList;
import org.jeecg.common.api.vo.Result;
import org.jeecg.modules.commonComment.entity.CommonComment;
import org.jeecg.modules.commonHome.entity.CommonHome;
import org.jeecg.modules.commonNews.entity.CommonNews;
import org.springframework.web.bind.annotation.RequestHeader;

import javax.servlet.http.HttpServletRequest;

public interface ApiIndexService {

    //获取通知公告
    Result<?> getNotice();


   //首页分类接口
    Result<?> getHouseType();

    //房源搜索条件-类型
    Result<?> getHouseIconClass();

    //房源搜索条件-价格
    Result<?> getHousePrice();

    //房源搜索条件-区域
    Result<?> getHouseArea();

    //房源搜索条件-年限
    Result<?> getHouseYear();


    Result<?> getAccountCode(String token);



    //根据租房分类信息获取租房带分页列表信息
//    Result<?> getHousePageList(HousePageList bean,
//                               String priceId,
//                               String  areaId,
//                               String yearId,
//                               String typeId, HttpServletRequest req);

 Result<?> getHousePageList(HousePageList bean,
                            CommonHomeBo bo, HttpServletRequest req);

    //根据标识获取租房详情
    Result<?> getHouseDetail(String houseId);

    //查询我发布的房源列表带分页
    Result<?> getMyHousePageList(String token,HousePageList bean);

    //发布或编辑房源
    Result<?> saveOrUpdateHouse(String token, CommonHome home);

    //删除房源信息
    Result<?> deleteHouse(String token,String houseId);


    //经济人账号密码登录
    Result<?> login(String token,String username, String password);


    //房东输入邀请码登录
    Result<?> loginByInviteCode(String token,String inviteCode);


    //获取首页图标的接口
    Result<?> getIndexIcon();


    //获取发现列表页面数据带分页
    Result<?> getFindPageList(HousePageList bean);

    //发布或编辑发现
    Result<?> saveOrUpdateFind(String token, CommonNews news);


    //获取发现列表详情
    Result<?> getFindDetail(String houseId);



    //根据房源标识查询房源的评论列表带分页
    Result<?> getCommentPageList(String houseId,HousePageList bean);

    //发表评论
    Result<?> saveComment(String token, CommonComment comment);

    //删除自己发的评论
    Result<?> deleteComment(String token,String commentId);


}
